<?php
/**
 * Plugin Name: YayMail Addon for B2BKing
 * Plugin URI: https://yaycommerce.com/yaymail-woocommerce-email-customizer/
 * Description: Customize templates for B2BKing plugin
 * Version: 1.2
 * Author: YayCommerce
 * Author URI: https://yaycommerce.com
 * Text Domain: yaymail
 * WC requires at least: 3.0.0
 * WC tested up to: 7.9.0
 * Domain Path: /i18n/languages/
 */

namespace YayMailB2BKing;

defined( 'ABSPATH' ) || exit;
spl_autoload_register(
	function ( $class ) {
		$prefix   = __NAMESPACE__;
		$base_dir = __DIR__ . '/views';

		$len = strlen( $prefix );
		if ( strncmp( $prefix, $class, $len ) !== 0 ) {
			return;
		}

		$relative_class_name = substr( $class, $len );

		$file = $base_dir . str_replace( '\\', '/', $relative_class_name ) . '.php';

		if ( file_exists( $file ) ) {
			require $file;
		}
	}
);

// Add action link customize
add_filter( 'plugin_action_links_' . plugin_basename( __FILE__ ), 'YayMailB2BKing\\yaymail_addon_add_action_links' );
function yaymail_addon_add_action_links( $actions ) {

	if ( defined( 'YAYMAIL_PREFIX' ) ) {
		$links   = array(
			'<a href="' . admin_url( 'admin.php?page=yaymail-settings' ) . '" aria-label="' . esc_attr__( 'View WooCommerce Email Builder', 'yaymail' ) . '">' . esc_html__( 'Start Customizing', 'yaymail' ) . '</a>',
		);
		$actions = array_merge( $links, $actions );
	}
	return $actions;
}

// Add action link docs and support
add_filter( 'plugin_row_meta', 'YayMailB2BKing\\yaymail_addon_custom_plugin_row_meta', 10, 2 );
function yaymail_addon_custom_plugin_row_meta( $plugin_meta, $plugin_file ) {

	if ( strpos( $plugin_file, plugin_basename( __FILE__ ) ) !== false ) {
		$new_links = array(
			'docs'    => '<a href="https://yaycommerce.gitbook.io/yaymail/" aria-label="' . esc_attr__( 'View YayMail documentation', 'yaymail' ) . '">' . esc_html__( 'Docs', 'yaymail' ) . '</a>',
			'support' => '<a href="https://yaycommerce.com/support/" aria-label="' . esc_attr__( 'Visit community forums', 'yaymail' ) . '">' . esc_html__( 'Support', 'yaymail' ) . '</a>',
		);

		$plugin_meta = array_merge( $plugin_meta, $new_links );
	}

	return $plugin_meta;
}

// Add action notice
add_action( 'after_plugin_row_' . plugin_basename( __FILE__ ), 'YayMailB2BKing\\yaymail_addon_add_notification_after_plugin_row', 10, 2 );
function yaymail_addon_add_notification_after_plugin_row( $plugin_file, $plugin_data ) {
	$wp_list_table = _get_list_table( 'WP_MS_Themes_List_Table' );
	?>
	<script>
	var plugin_row_element = document.querySelector('tr[data-plugin="<?php echo esc_js(  plugin_basename( __FILE__ ) ); ?>"]');
	plugin_row_element.classList.add('update');
	</script>
	<?php
	$notice_addon = '<div class="notice inline notice-warning notice-alt"><p>';
	// Translators: Placeholders are opening and closing Addon Name tags.
	$notice_addon .= sprintf( esc_html__( 'In order to customize templates of %1$s, please install %2$s first.', 'yaymail' ), '<strong>B2BKing</strong>', '<strong>B2BKing</strong>' );
	$notice_addon .= '</p> </div>';

	$notice_yaymail  = '<div class="notice inline notice-warning notice-alt"><p>';
	$notice_yaymail .= esc_html__( 'To use this addon, you need to install and activate YayMail plugin. Get ', 'yaymail' ) . '<a href="' . esc_url( 'https://wordpress.org/plugins/yaymail/' ) . '">' . esc_html__( 'YayMail Free', 'yaymail' ) . '</a> or <a href="' . esc_url( 'https://yaycommerce.com/yaymail-woocommerce-email-customizer/' ) . '">' . esc_html__( 'YayMail Pro', 'yaymail' ) . '</a>';
	$notice_yaymail .= '</p> </div>';

	echo wp_kses_post( '<tr class="plugin-update-tr' . ( is_plugin_active( $plugin_file ) ? ' active' : '' ) . '"><td colspan="' . esc_attr( $wp_list_table->get_column_count() ) . '" class="plugin-update colspanchange" >' );
	if ( ! function_exists( 'YayMail\\init' ) ) {
		echo wp_kses_post( $notice_yaymail );
	}
	if ( ! function_exists('b2bking_activate') ) {
		echo wp_kses_post( $notice_addon );
	}
	echo wp_kses_post( '</td></tr>' );

}

function yaymail_dependence() {
	wp_enqueue_script( 'yaymail-b2bking', plugin_dir_url( __FILE__ ) . 'assets/dist/js/app.js', array(), '1.0', true );
	wp_enqueue_style( 'yaymail-b2bking', plugin_dir_url( __FILE__ ) . 'assets/dist/css/app.css', array(), '1.0' );
}
add_action( 'yaymail_before_enqueue_dependence', 'YayMailB2BKing\\yaymail_dependence' );


add_filter(
	'yaymail_plugins',
	function( $plugins ) {
		$plugins[] = array(
			'plugin_name'      => 'B2BKing', // --> CHANGE HERE => name of plugin (maybe name of the class)
			'addon_components' => array( 'B2BKingInformation' ), // CHANGE HERE => main-name required
			'template_name'    => array( 'b2bking_new_customer_email', 'b2bking_new_customer_requires_approval_email', 'b2bking_new_message_email', 'b2bking_new_offer_email', 'b2bking_your_account_approved_email' ),
		);
		return $plugins;
	},
	10,
	1
);

// Action create template default
add_filter( 'YaymailNewTempalteDefault', 'YayMailB2BKing\\yaymail_new_template_default', 100, 3 );
function yaymail_new_template_default( $array, $key, $value ) {

	if ( 'B2bking_New_Customer_Email' == $key
		|| 'B2bking_New_Customer_Requires_Approval_Email' == $key
		|| 'B2bking_New_Message_Email' == $key
		|| 'B2bking_Your_Account_Approved_Email' == $key
	) {
		$getHeading          = $value->heading;
		$defaultB2BKing = templateDefault\DefaultB2BKing::getTemplates( $value->id, $getHeading );
		return $defaultB2BKing;
	} elseif ( 'B2bking_New_Offer_Email' == $key ) {
		$getHeading          = $value->heading;
		$defaultB2BKingOffer = templateDefault\DefaultB2BKingOffer::getTemplates( $value->id, $getHeading );
		return $defaultB2BKingOffer;
	}
	return $array;
}

/*
Action to defined shortcode
$arrData[0] : $custom_shortcode
$arrData[1] : $args
$arrData[2] : $templateName
*/

add_action(
	'yaymail_addon_defined_shorcode',
	function( $arrData ) {
		$templateWooSubscription = array( 'b2bking_new_customer_email', 'b2bking_new_customer_requires_approval_email', 'b2bking_new_message_email', 'b2bking_new_offer_email', 'b2bking_your_account_approved_email' );
		if ( in_array( $arrData[2], $templateWooSubscription ) ) {
			$arrData[0]->setOrderId( 0, isset( $arrData[1]['sent_to_admin'] ) ? $arrData[1]['sent_to_admin'] : false, $arrData[1] );
			$arrData[0]->shortCodesOrderDefined( isset( $arrData[1]['sent_to_admin'] ) ? $arrData[1]['sent_to_admin'] : false, $arrData[1] );
		}
	}
);

// Filter to defined template
add_filter(
	'yaymail_addon_defined_template',
	function( $result, $template ) {
		$templateWooSubscription = array( 'b2bking_new_customer_email', 'b2bking_new_customer_requires_approval_email', 'b2bking_new_message_email', 'b2bking_new_offer_email', 'b2bking_your_account_approved_email' );
		if ( in_array( $template, $templateWooSubscription ) ) {
			return true;
		}
		return $result;
	},
	10,
	2
);

// CHANGE HERE
// Filter to add template to Vuex
add_filter(
	'yaymail_addon_templates',
	function( $addon_templates, $order, $post_id ) {
		$components = apply_filters( 'yaymail_plugins', array() );
		$position   = '';
		foreach ( $components as $key => $component ) {
			if ( $component['plugin_name'] === 'B2BKing' ) {
				$position = $key;
				break;
			}
		}
		foreach ( $components[$position]['addon_components'] as $key => $component ) {
			ob_start();
			do_action( 'YaymailAddon' . $component . 'Vue', $order, $post_id );
			$html = ob_get_contents();
			ob_end_clean();
			$addon_templates['b2bking'] = array_merge( isset( $addon_templates['b2bking'] ) ? $addon_templates['b2bking'] : array(), array( $component . 'Vue' => $html ) );
		}
		return $addon_templates;
	},
	10,
	3
);

/** SHORTCODE WILL DO HERE */
// Display shortcode in core
add_filter(
	'yaymail_list_shortcodes',
	function( $shortcode_list ) {
		$shortcode_list[] = array(
			'plugin' => 'B2BKing',
			'shortcode' => array(
				['[yaymail_addon_new_customer_user_login]', 'User login'],
				['[yaymail_addon_new_customer_user_email]', 'User email'],
				['[yaymail_addon_new_customer_user_id]', 'User id]'],
				['[yaymail_addon_template_new_customer]', 'Template new customer'],
				['[yaymail_addon_template_new_customer_approval]', 'Template new customer approval'],
				['[yaymail_addon_template_new_message]', 'Template new message'],
				['[yaymail_addon_template_new_message_request]', 'Template new message request'],
				['[yaymail_addon_b2bking_account_approved_first_name]', 'Account approved first name'],
				['[yaymail_addon_b2bking_account_approved_last_name]', 'Account approved last name'],
				['[yaymail_addon_b2bking_account_approved_email]', 'Account approved email'],
			)
		);

		return $shortcode_list;
	},
	10,
	1
);
// Add new shortcode to shortcodes list
add_filter(
	'yaymail_shortcodes',
	function( $shortcode_list ) {
		$shortcode_list[] = 'yaymail_addon_new_customer_user_login';
		$shortcode_list[] = 'yaymail_addon_new_customer_user_email';
		$shortcode_list[] = 'yaymail_addon_new_customer_user_id';

		//shortcode for template
		$shortcode_list[] = 'yaymail_addon_template_new_customer';
		$shortcode_list[] = 'yaymail_addon_template_new_customer_approval';
		$shortcode_list[] = 'yaymail_addon_template_new_message';
		$shortcode_list[] = 'yaymail_addon_template_new_message_request';
		$shortcode_list[] = 'yaymail_addon_b2bking_account_approved_first_name';
		$shortcode_list[] = 'yaymail_addon_b2bking_account_approved_last_name';
		$shortcode_list[] = 'yaymail_addon_b2bking_account_approved_email';
		return $shortcode_list;
	},
	10,
	1
);

// Create shortcode
add_filter(
	'yaymail_do_shortcode',
	function( $shortcode_list, $yaymail_informations, $args = array() ) {
		$shortcode_list['[yaymail_addon_new_customer_user_login]'] = yaymail_addon_new_customer_user_login( $yaymail_informations, $args );
		$shortcode_list['[yaymail_addon_new_customer_user_email]'] = yaymail_addon_new_customer_user_email( $yaymail_informations, $args );
		$shortcode_list['[yaymail_addon_new_customer_user_id]'] = yaymail_addon_new_customer_user_id( $yaymail_informations, $args );

		$shortcode_list['[yaymail_addon_template_new_customer]'] = yaymail_addon_template_new_customer( $yaymail_informations, $args );
		$shortcode_list['[yaymail_addon_template_new_customer_approval]'] = yaymail_addon_template_new_customer_approval( $yaymail_informations, $args );
		$shortcode_list['[yaymail_addon_template_new_message]'] = yaymail_addon_template_new_message( $yaymail_informations, $args );
		$shortcode_list['[yaymail_addon_template_new_message_request]'] = yaymail_addon_template_new_message_request( $yaymail_informations, $args );
		$shortcode_list['[yaymail_addon_b2bking_account_approved_first_name]'] = yaymail_addon_b2bking_account_approved_first_name( $yaymail_informations, $args );
		$shortcode_list['[yaymail_addon_b2bking_account_approved_last_name]'] = yaymail_addon_b2bking_account_approved_last_name( $yaymail_informations, $args );
		$shortcode_list['[yaymail_addon_b2bking_account_approved_email]'] = yaymail_addon_b2bking_account_approved_email( $yaymail_informations, $args );
		return $shortcode_list;
	},
	10,
	3
);

function yaymail_addon_b2bking_account_approved_email( $yaymail_informations, $args = array() ) {
	if(isset($args['email']) && !empty($args['email']->recipient)) {
		return $args['email']->recipient;
	}
	return 'test@gmail.com';
}

function yaymail_addon_b2bking_account_approved_last_name( $yaymail_informations, $args = array() ) {
	if(isset($args['email'])) {
		$user = get_user_by( 'email', sanitize_email( $args['email']->recipient ) );
		if ( !empty($user) && isset( $user->user_email ) && ! empty( get_user_meta( $user->ID, 'last_name', true ) ) ) {
			 return get_user_meta( $user->ID, 'last_name', true );
		}
	}
	return 'last_name';
}

function yaymail_addon_b2bking_account_approved_first_name( $yaymail_informations, $args = array() ) {
	if(isset($args['email'])) {
		$user = get_user_by( 'email', sanitize_email( $args['email']->recipient ) );
		if (!empty($user) &&  isset( $user->user_email ) && ! empty( get_user_meta( $user->ID, 'first_name', true ) ) ) {
			 return get_user_meta( $user->ID, 'first_name', true );
		}
	}
	return 'first_name';
}

function yaymail_addon_template_new_message_request( $yaymail_informations, $args = array() ) {
	if( isset($args['message']) && isset($args['userid']) && isset($args['conversationid']) ) {
		$message = $args['message'];
		$userid = $args['userid'];
		$conversationid = $args['conversationid'];
		ob_start();
		include plugin_dir_path( __FILE__ ) . '/views/template/yaymail_addon_template_new_message_request.php';
		$html = ob_get_contents();
		ob_end_clean();
		return $html;
	} else {
		ob_start();
		include plugin_dir_path( __FILE__ ) . '/views/template/TemplateSample/yaymail_addon_template_new_message.php';
		$html = ob_get_contents();
		ob_end_clean();
		return $html;
	}
}

function yaymail_addon_template_new_message( $yaymail_informations, $args = array() ) {
	if( isset($args['message']) && isset($args['userid']) && isset($args['conversationid']) ) {
		$message = $args['message'];
		$userid = $args['userid'];
		$conversationid = $args['conversationid'];
		ob_start();
		include plugin_dir_path( __FILE__ ) . '/views/template/yaymail_addon_template_new_message.php';
		$html = ob_get_contents();
		ob_end_clean();
		return $html;
	} else {
		ob_start();
		include plugin_dir_path( __FILE__ ) . '/views/template/TemplateSample/yaymail_addon_template_new_message.php';
		$html = ob_get_contents();
		ob_end_clean();
		return $html;
	}
}

function yaymail_addon_template_new_customer_approval( $yaymail_informations, $args = array() ) {
	if( isset($args['user_login']) ) {
		$user_login = $args['user_login'];
		ob_start();
		include plugin_dir_path( __FILE__ ) . '/views/template/yaymail_addon_template_new_customer_approval.php';
		$html = ob_get_contents();
		ob_end_clean();
		return $html;
	} else {
		ob_start();
		include plugin_dir_path( __FILE__ ) . '/views/template/TemplateSample/yaymail_addon_template_new_customer_approval.php';
		$html = ob_get_contents();
		ob_end_clean();
		return $html;
	}
}

function yaymail_addon_template_new_customer( $yaymail_informations, $args = array() ) {
	if( isset($args['user_login']) ) {
		$user_login = $args['user_login'];
		ob_start();
		include plugin_dir_path( __FILE__ ) . '/views/template/yaymail_addon_template_new_customer.php';
		$html = ob_get_contents();
		ob_end_clean();
		return $html;
	} else {
		ob_start();
		include plugin_dir_path( __FILE__ ) . '/views/template/TemplateSample/yaymail_addon_template_new_customer.php';
		$html = ob_get_contents();
		ob_end_clean();
		return $html;
	}
}

function yaymail_addon_new_customer_user_id( $yaymail_informations, $args = array() ) {
	if( isset($args['user_login']) ) {
		$user_login = $args['user_login'];
		$user = get_user_by('login', $user_login);
		return $user->ID;
	}
	return '1';
}

function yaymail_addon_new_customer_user_email( $yaymail_informations, $args = array() ) {
	if( isset($args['user_login']) ) {
		$user_login = $args['user_login'];
		$user = get_user_by('login', $user_login);
		$user_email = $user->user_email;
		return $user_email;
	}
	return 'user_email';
}

function yaymail_addon_new_customer_user_login( $yaymail_informations, $args = array() ) {
	if( isset($args['user_login']) ) {
		return $args['user_login'];
	}
	return 'user_login';
}

/** END SHORTCODE */


// Create HTML with Vue syntax to display in Vue
// CHANGE HERE => Name of action follow : YaymailAddon + main-name + Vue
// CHANGE SOURCE VUE TOO
add_action( 'YaymailAddonB2BKingInformationVue', 'YayMailB2BKing\\yith_vendor_information_vue', 100, 5 );
function yith_vendor_information_vue( $order, $postID = '' ) {
	ob_start();
	include plugin_dir_path( __FILE__ ) . '/views/vue-template/YaymailAddonB2BKingInformation.php';
	$html = ob_get_contents();
	ob_end_clean();
	echo $html;
}

// Create HTML to display when send mail
// CHANGE HERE => Name of action follow: YaymailAddon + main-name
add_action( 'YaymailAddonB2BKingInformation', 'YayMailB2BKing\\yaymail_addon_yith_vendor_information', 100, 5 );
function yaymail_addon_yith_vendor_information( $args = array(), $attrs = array(), $general_attrs = array(), $id = '', $postID = '' ) {
	if ( isset( $args['message'] ) && isset( $args['offerid'] ) && isset( $args['offerlink'] )) {
		$message = $args['message'];
		$offerid = $args['offerid'];
		$offerlink = $args['offerlink'];
		ob_start();
		include plugin_dir_path( __FILE__ ) . '/views/template/YaymailAddonB2BKingInformation.php';
		$html = ob_get_contents();
		ob_end_clean();
		$html = do_shortcode( $html );
		echo wp_kses_post( $html );
	} else {
		ob_start();
		include plugin_dir_path( __FILE__ ) . '/views/template/TemplateSample/YaymailAddonB2BKingInformation.php';
		$html = ob_get_contents();
		ob_end_clean();
		$html = do_shortcode( $html );
		echo wp_kses_post( $html );
	}
}




